# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from iotexetl.rpc.iotexapi import api_pb2 as proto_dot_api_dot_api__pb2


class APIServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetAccount = channel.unary_unary(
                '/iotexapi.APIService/GetAccount',
                request_serializer=proto_dot_api_dot_api__pb2.GetAccountRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.GetAccountResponse.FromString,
                )
        self.GetActions = channel.unary_unary(
                '/iotexapi.APIService/GetActions',
                request_serializer=proto_dot_api_dot_api__pb2.GetActionsRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.GetActionsResponse.FromString,
                )
        self.GetBlockMetas = channel.unary_unary(
                '/iotexapi.APIService/GetBlockMetas',
                request_serializer=proto_dot_api_dot_api__pb2.GetBlockMetasRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.GetBlockMetasResponse.FromString,
                )
        self.GetChainMeta = channel.unary_unary(
                '/iotexapi.APIService/GetChainMeta',
                request_serializer=proto_dot_api_dot_api__pb2.GetChainMetaRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.GetChainMetaResponse.FromString,
                )
        self.GetServerMeta = channel.unary_unary(
                '/iotexapi.APIService/GetServerMeta',
                request_serializer=proto_dot_api_dot_api__pb2.GetServerMetaRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.GetServerMetaResponse.FromString,
                )
        self.SendAction = channel.unary_unary(
                '/iotexapi.APIService/SendAction',
                request_serializer=proto_dot_api_dot_api__pb2.SendActionRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.SendActionResponse.FromString,
                )
        self.GetReceiptByAction = channel.unary_unary(
                '/iotexapi.APIService/GetReceiptByAction',
                request_serializer=proto_dot_api_dot_api__pb2.GetReceiptByActionRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.GetReceiptByActionResponse.FromString,
                )
        self.ReadContract = channel.unary_unary(
                '/iotexapi.APIService/ReadContract',
                request_serializer=proto_dot_api_dot_api__pb2.ReadContractRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.ReadContractResponse.FromString,
                )
        self.SuggestGasPrice = channel.unary_unary(
                '/iotexapi.APIService/SuggestGasPrice',
                request_serializer=proto_dot_api_dot_api__pb2.SuggestGasPriceRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.SuggestGasPriceResponse.FromString,
                )
        self.EstimateGasForAction = channel.unary_unary(
                '/iotexapi.APIService/EstimateGasForAction',
                request_serializer=proto_dot_api_dot_api__pb2.EstimateGasForActionRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.EstimateGasForActionResponse.FromString,
                )
        self.EstimateActionGasConsumption = channel.unary_unary(
                '/iotexapi.APIService/EstimateActionGasConsumption',
                request_serializer=proto_dot_api_dot_api__pb2.EstimateActionGasConsumptionRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.EstimateActionGasConsumptionResponse.FromString,
                )
        self.ReadState = channel.unary_unary(
                '/iotexapi.APIService/ReadState',
                request_serializer=proto_dot_api_dot_api__pb2.ReadStateRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.ReadStateResponse.FromString,
                )
        self.GetEpochMeta = channel.unary_unary(
                '/iotexapi.APIService/GetEpochMeta',
                request_serializer=proto_dot_api_dot_api__pb2.GetEpochMetaRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.GetEpochMetaResponse.FromString,
                )
        self.GetRawBlocks = channel.unary_unary(
                '/iotexapi.APIService/GetRawBlocks',
                request_serializer=proto_dot_api_dot_api__pb2.GetRawBlocksRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.GetRawBlocksResponse.FromString,
                )
        self.GetLogs = channel.unary_unary(
                '/iotexapi.APIService/GetLogs',
                request_serializer=proto_dot_api_dot_api__pb2.GetLogsRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.GetLogsResponse.FromString,
                )
        self.GetEvmTransfersByActionHash = channel.unary_unary(
                '/iotexapi.APIService/GetEvmTransfersByActionHash',
                request_serializer=proto_dot_api_dot_api__pb2.GetEvmTransfersByActionHashRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.GetEvmTransfersByActionHashResponse.FromString,
                )
        self.GetEvmTransfersByBlockHeight = channel.unary_unary(
                '/iotexapi.APIService/GetEvmTransfersByBlockHeight',
                request_serializer=proto_dot_api_dot_api__pb2.GetEvmTransfersByBlockHeightRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.GetEvmTransfersByBlockHeightResponse.FromString,
                )
        self.GetTransactionLogByActionHash = channel.unary_unary(
                '/iotexapi.APIService/GetTransactionLogByActionHash',
                request_serializer=proto_dot_api_dot_api__pb2.GetTransactionLogByActionHashRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.GetTransactionLogByActionHashResponse.FromString,
                )
        self.GetTransactionLogByBlockHeight = channel.unary_unary(
                '/iotexapi.APIService/GetTransactionLogByBlockHeight',
                request_serializer=proto_dot_api_dot_api__pb2.GetTransactionLogByBlockHeightRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.GetTransactionLogByBlockHeightResponse.FromString,
                )
        self.StreamBlocks = channel.unary_stream(
                '/iotexapi.APIService/StreamBlocks',
                request_serializer=proto_dot_api_dot_api__pb2.StreamBlocksRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.StreamBlocksResponse.FromString,
                )
        self.StreamLogs = channel.unary_stream(
                '/iotexapi.APIService/StreamLogs',
                request_serializer=proto_dot_api_dot_api__pb2.StreamLogsRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.StreamLogsResponse.FromString,
                )
        self.GetElectionBuckets = channel.unary_unary(
                '/iotexapi.APIService/GetElectionBuckets',
                request_serializer=proto_dot_api_dot_api__pb2.GetElectionBucketsRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.GetElectionBucketsResponse.FromString,
                )


class APIServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def GetAccount(self, request, context):
        """get the address detail of an address
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetActions(self, request, context):
        """get action(s) by:
        1. start index and action count
        2. action hash
        3. address with start index and action count
        4. get unconfirmed actions by address with start index and action count
        5. block hash with start index and action count
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetBlockMetas(self, request, context):
        """get block metadata(s) by:
        1. start index and block count
        2. block hash
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetChainMeta(self, request, context):
        """get chain metadata
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetServerMeta(self, request, context):
        """get server version
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SendAction(self, request, context):
        """sendAction
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetReceiptByAction(self, request, context):
        """get receipt by action Hash
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadContract(self, request, context):
        """TODO: read contract
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SuggestGasPrice(self, request, context):
        """suggest gas price
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EstimateGasForAction(self, request, context):
        """estimate gas for action, to be deprecated
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def EstimateActionGasConsumption(self, request, context):
        """estimate gas for action and transfer not sealed
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReadState(self, request, context):
        """read state from blockchain
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEpochMeta(self, request, context):
        """get epoch metadata
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRawBlocks(self, request, context):
        """get raw blocks data
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLogs(self, request, context):
        """get logs filtered by contract address and topics
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEvmTransfersByActionHash(self, request, context):
        """
        evm transfers APIs

        Deprecated
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetEvmTransfersByBlockHeight(self, request, context):
        """Deprecated
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionLogByActionHash(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionLogByBlockHeight(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamBlocks(self, request, context):
        """
        below are streaming APIs

        get block info in stream
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamLogs(self, request, context):
        """get logs filtered by contract address and topics in stream
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetElectionBuckets(self, request, context):
        """
        election APIs
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_APIServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetAccount': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAccount,
                    request_deserializer=proto_dot_api_dot_api__pb2.GetAccountRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.GetAccountResponse.SerializeToString,
            ),
            'GetActions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetActions,
                    request_deserializer=proto_dot_api_dot_api__pb2.GetActionsRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.GetActionsResponse.SerializeToString,
            ),
            'GetBlockMetas': grpc.unary_unary_rpc_method_handler(
                    servicer.GetBlockMetas,
                    request_deserializer=proto_dot_api_dot_api__pb2.GetBlockMetasRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.GetBlockMetasResponse.SerializeToString,
            ),
            'GetChainMeta': grpc.unary_unary_rpc_method_handler(
                    servicer.GetChainMeta,
                    request_deserializer=proto_dot_api_dot_api__pb2.GetChainMetaRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.GetChainMetaResponse.SerializeToString,
            ),
            'GetServerMeta': grpc.unary_unary_rpc_method_handler(
                    servicer.GetServerMeta,
                    request_deserializer=proto_dot_api_dot_api__pb2.GetServerMetaRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.GetServerMetaResponse.SerializeToString,
            ),
            'SendAction': grpc.unary_unary_rpc_method_handler(
                    servicer.SendAction,
                    request_deserializer=proto_dot_api_dot_api__pb2.SendActionRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.SendActionResponse.SerializeToString,
            ),
            'GetReceiptByAction': grpc.unary_unary_rpc_method_handler(
                    servicer.GetReceiptByAction,
                    request_deserializer=proto_dot_api_dot_api__pb2.GetReceiptByActionRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.GetReceiptByActionResponse.SerializeToString,
            ),
            'ReadContract': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadContract,
                    request_deserializer=proto_dot_api_dot_api__pb2.ReadContractRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.ReadContractResponse.SerializeToString,
            ),
            'SuggestGasPrice': grpc.unary_unary_rpc_method_handler(
                    servicer.SuggestGasPrice,
                    request_deserializer=proto_dot_api_dot_api__pb2.SuggestGasPriceRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.SuggestGasPriceResponse.SerializeToString,
            ),
            'EstimateGasForAction': grpc.unary_unary_rpc_method_handler(
                    servicer.EstimateGasForAction,
                    request_deserializer=proto_dot_api_dot_api__pb2.EstimateGasForActionRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.EstimateGasForActionResponse.SerializeToString,
            ),
            'EstimateActionGasConsumption': grpc.unary_unary_rpc_method_handler(
                    servicer.EstimateActionGasConsumption,
                    request_deserializer=proto_dot_api_dot_api__pb2.EstimateActionGasConsumptionRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.EstimateActionGasConsumptionResponse.SerializeToString,
            ),
            'ReadState': grpc.unary_unary_rpc_method_handler(
                    servicer.ReadState,
                    request_deserializer=proto_dot_api_dot_api__pb2.ReadStateRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.ReadStateResponse.SerializeToString,
            ),
            'GetEpochMeta': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEpochMeta,
                    request_deserializer=proto_dot_api_dot_api__pb2.GetEpochMetaRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.GetEpochMetaResponse.SerializeToString,
            ),
            'GetRawBlocks': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRawBlocks,
                    request_deserializer=proto_dot_api_dot_api__pb2.GetRawBlocksRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.GetRawBlocksResponse.SerializeToString,
            ),
            'GetLogs': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLogs,
                    request_deserializer=proto_dot_api_dot_api__pb2.GetLogsRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.GetLogsResponse.SerializeToString,
            ),
            'GetEvmTransfersByActionHash': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEvmTransfersByActionHash,
                    request_deserializer=proto_dot_api_dot_api__pb2.GetEvmTransfersByActionHashRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.GetEvmTransfersByActionHashResponse.SerializeToString,
            ),
            'GetEvmTransfersByBlockHeight': grpc.unary_unary_rpc_method_handler(
                    servicer.GetEvmTransfersByBlockHeight,
                    request_deserializer=proto_dot_api_dot_api__pb2.GetEvmTransfersByBlockHeightRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.GetEvmTransfersByBlockHeightResponse.SerializeToString,
            ),
            'GetTransactionLogByActionHash': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionLogByActionHash,
                    request_deserializer=proto_dot_api_dot_api__pb2.GetTransactionLogByActionHashRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.GetTransactionLogByActionHashResponse.SerializeToString,
            ),
            'GetTransactionLogByBlockHeight': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionLogByBlockHeight,
                    request_deserializer=proto_dot_api_dot_api__pb2.GetTransactionLogByBlockHeightRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.GetTransactionLogByBlockHeightResponse.SerializeToString,
            ),
            'StreamBlocks': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamBlocks,
                    request_deserializer=proto_dot_api_dot_api__pb2.StreamBlocksRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.StreamBlocksResponse.SerializeToString,
            ),
            'StreamLogs': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamLogs,
                    request_deserializer=proto_dot_api_dot_api__pb2.StreamLogsRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.StreamLogsResponse.SerializeToString,
            ),
            'GetElectionBuckets': grpc.unary_unary_rpc_method_handler(
                    servicer.GetElectionBuckets,
                    request_deserializer=proto_dot_api_dot_api__pb2.GetElectionBucketsRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.GetElectionBucketsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'iotexapi.APIService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class APIService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def GetAccount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/iotexapi.APIService/GetAccount',
            proto_dot_api_dot_api__pb2.GetAccountRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.GetAccountResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetActions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/iotexapi.APIService/GetActions',
            proto_dot_api_dot_api__pb2.GetActionsRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.GetActionsResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetBlockMetas(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/iotexapi.APIService/GetBlockMetas',
            proto_dot_api_dot_api__pb2.GetBlockMetasRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.GetBlockMetasResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetChainMeta(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/iotexapi.APIService/GetChainMeta',
            proto_dot_api_dot_api__pb2.GetChainMetaRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.GetChainMetaResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetServerMeta(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/iotexapi.APIService/GetServerMeta',
            proto_dot_api_dot_api__pb2.GetServerMetaRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.GetServerMetaResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SendAction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/iotexapi.APIService/SendAction',
            proto_dot_api_dot_api__pb2.SendActionRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.SendActionResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetReceiptByAction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/iotexapi.APIService/GetReceiptByAction',
            proto_dot_api_dot_api__pb2.GetReceiptByActionRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.GetReceiptByActionResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadContract(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/iotexapi.APIService/ReadContract',
            proto_dot_api_dot_api__pb2.ReadContractRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.ReadContractResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SuggestGasPrice(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/iotexapi.APIService/SuggestGasPrice',
            proto_dot_api_dot_api__pb2.SuggestGasPriceRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.SuggestGasPriceResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EstimateGasForAction(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/iotexapi.APIService/EstimateGasForAction',
            proto_dot_api_dot_api__pb2.EstimateGasForActionRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.EstimateGasForActionResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def EstimateActionGasConsumption(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/iotexapi.APIService/EstimateActionGasConsumption',
            proto_dot_api_dot_api__pb2.EstimateActionGasConsumptionRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.EstimateActionGasConsumptionResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReadState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/iotexapi.APIService/ReadState',
            proto_dot_api_dot_api__pb2.ReadStateRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.ReadStateResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEpochMeta(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/iotexapi.APIService/GetEpochMeta',
            proto_dot_api_dot_api__pb2.GetEpochMetaRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.GetEpochMetaResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRawBlocks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/iotexapi.APIService/GetRawBlocks',
            proto_dot_api_dot_api__pb2.GetRawBlocksRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.GetRawBlocksResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/iotexapi.APIService/GetLogs',
            proto_dot_api_dot_api__pb2.GetLogsRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.GetLogsResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEvmTransfersByActionHash(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/iotexapi.APIService/GetEvmTransfersByActionHash',
            proto_dot_api_dot_api__pb2.GetEvmTransfersByActionHashRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.GetEvmTransfersByActionHashResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetEvmTransfersByBlockHeight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/iotexapi.APIService/GetEvmTransfersByBlockHeight',
            proto_dot_api_dot_api__pb2.GetEvmTransfersByBlockHeightRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.GetEvmTransfersByBlockHeightResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTransactionLogByActionHash(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/iotexapi.APIService/GetTransactionLogByActionHash',
            proto_dot_api_dot_api__pb2.GetTransactionLogByActionHashRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.GetTransactionLogByActionHashResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTransactionLogByBlockHeight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/iotexapi.APIService/GetTransactionLogByBlockHeight',
            proto_dot_api_dot_api__pb2.GetTransactionLogByBlockHeightRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.GetTransactionLogByBlockHeightResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamBlocks(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/iotexapi.APIService/StreamBlocks',
            proto_dot_api_dot_api__pb2.StreamBlocksRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.StreamBlocksResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StreamLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/iotexapi.APIService/StreamLogs',
            proto_dot_api_dot_api__pb2.StreamLogsRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.StreamLogsResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetElectionBuckets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/iotexapi.APIService/GetElectionBuckets',
            proto_dot_api_dot_api__pb2.GetElectionBucketsRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.GetElectionBucketsResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)


class TransactionLogServiceStub(object):
    """experiment
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GetTransactionLogByActionHash = channel.unary_unary(
                '/iotexapi.TransactionLogService/GetTransactionLogByActionHash',
                request_serializer=proto_dot_api_dot_api__pb2.GetTransactionLogByActionHashRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.GetTransactionLogByActionHashResponse.FromString,
                )
        self.GetTransactionLogByBlockHeight = channel.unary_unary(
                '/iotexapi.TransactionLogService/GetTransactionLogByBlockHeight',
                request_serializer=proto_dot_api_dot_api__pb2.GetTransactionLogByBlockHeightRequest.SerializeToString,
                response_deserializer=proto_dot_api_dot_api__pb2.GetTransactionLogByBlockHeightResponse.FromString,
                )


class TransactionLogServiceServicer(object):
    """experiment
    """

    def GetTransactionLogByActionHash(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTransactionLogByBlockHeight(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TransactionLogServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GetTransactionLogByActionHash': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionLogByActionHash,
                    request_deserializer=proto_dot_api_dot_api__pb2.GetTransactionLogByActionHashRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.GetTransactionLogByActionHashResponse.SerializeToString,
            ),
            'GetTransactionLogByBlockHeight': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTransactionLogByBlockHeight,
                    request_deserializer=proto_dot_api_dot_api__pb2.GetTransactionLogByBlockHeightRequest.FromString,
                    response_serializer=proto_dot_api_dot_api__pb2.GetTransactionLogByBlockHeightResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'iotexapi.TransactionLogService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TransactionLogService(object):
    """experiment
    """

    @staticmethod
    def GetTransactionLogByActionHash(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/iotexapi.TransactionLogService/GetTransactionLogByActionHash',
            proto_dot_api_dot_api__pb2.GetTransactionLogByActionHashRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.GetTransactionLogByActionHashResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetTransactionLogByBlockHeight(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/iotexapi.TransactionLogService/GetTransactionLogByBlockHeight',
            proto_dot_api_dot_api__pb2.GetTransactionLogByBlockHeightRequest.SerializeToString,
            proto_dot_api_dot_api__pb2.GetTransactionLogByBlockHeightResponse.FromString,
            options, channel_credentials,
            call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/types/blockchain.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from iotexetl.rpc.iotextypes import action_pb2 as proto_dot_types_dot_action__pb2
from iotexetl.rpc.iotextypes import endorsement_pb2 as proto_dot_types_dot_endorsement__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/types/blockchain.proto',
  package='iotextypes',
  syntax='proto3',
  serialized_options=b'\n\"com.github.iotexproject.grpc.typesP\001Z5github.com/iotexproject/iotex-proto/golang/iotextypes',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1cproto/types/blockchain.proto\x12\niotextypes\x1a\x18proto/types/action.proto\x1a\x1dproto/types/endorsement.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"c\n\x0b\x42lockHeader\x12)\n\x04\x63ore\x18\x01 \x01(\x0b\x32\x1b.iotextypes.BlockHeaderCore\x12\x16\n\x0eproducerPubkey\x18\x02 \x01(\x0c\x12\x11\n\tsignature\x18\x03 \x01(\x0c\"\xca\x01\n\x0f\x42lockHeaderCore\x12\x0f\n\x07version\x18\x01 \x01(\r\x12\x0e\n\x06height\x18\x02 \x01(\x04\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x15\n\rprevBlockHash\x18\x04 \x01(\x0c\x12\x0e\n\x06txRoot\x18\x05 \x01(\x0c\x12\x18\n\x10\x64\x65ltaStateDigest\x18\x06 \x01(\x0c\x12\x13\n\x0breceiptRoot\x18\x07 \x01(\x0c\x12\x11\n\tlogsBloom\x18\x08 \x01(\x0c\"k\n\x0b\x42lockFooter\x12-\n\x0c\x65ndorsements\x18\x01 \x03(\x0b\x32\x17.iotextypes.Endorsement\x12-\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"0\n\tBlockBody\x12#\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32\x12.iotextypes.Action\"~\n\x05\x42lock\x12\'\n\x06header\x18\x01 \x01(\x0b\x32\x17.iotextypes.BlockHeader\x12#\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x15.iotextypes.BlockBody\x12\'\n\x06\x66ooter\x18\x03 \x01(\x0b\x32\x17.iotextypes.BlockFooter\"1\n\x08Receipts\x12%\n\x08receipts\x18\x01 \x03(\x0b\x32\x13.iotextypes.Receipt\"I\n\tEpochData\x12\x0b\n\x03num\x18\x01 \x01(\x04\x12\x0e\n\x06height\x18\x02 \x01(\x04\x12\x1f\n\x17gravityChainStartHeight\x18\x03 \x01(\x04\"t\n\tChainMeta\x12\x0e\n\x06height\x18\x01 \x01(\x04\x12\x12\n\nnumActions\x18\x02 \x01(\x03\x12\x0b\n\x03tps\x18\x03 \x01(\x03\x12$\n\x05\x65poch\x18\x04 \x01(\x0b\x32\x15.iotextypes.EpochData\x12\x10\n\x08tpsFloat\x18\x05 \x01(\x02\"\xef\x01\n\tBlockMeta\x12\x0c\n\x04hash\x18\x01 \x01(\t\x12\x0e\n\x06height\x18\x02 \x01(\x04\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nnumActions\x18\x04 \x01(\x03\x12\x17\n\x0fproducerAddress\x18\x05 \x01(\t\x12\x16\n\x0etransferAmount\x18\x06 \x01(\t\x12\x0e\n\x06txRoot\x18\x07 \x01(\t\x12\x13\n\x0breceiptRoot\x18\x08 \x01(\t\x12\x18\n\x10\x64\x65ltaStateDigest\x18\t \x01(\t\x12\x11\n\tlogsBloom\x18\n \x01(\t\"/\n\x0f\x42lockIdentifier\x12\x0c\n\x04hash\x18\x01 \x01(\t\x12\x0e\n\x06height\x18\x02 \x01(\x04\"h\n\x0b\x41\x63\x63ountMeta\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\t\x12\x0f\n\x07\x62\x61lance\x18\x02 \x01(\t\x12\r\n\x05nonce\x18\x03 \x01(\x04\x12\x14\n\x0cpendingNonce\x18\x04 \x01(\x04\x12\x12\n\nnumActions\x18\x05 \x01(\x04\x42]\n\"com.github.iotexproject.grpc.typesP\x01Z5github.com/iotexproject/iotex-proto/golang/iotextypesb\x06proto3'
  ,
  dependencies=[proto_dot_types_dot_action__pb2.DESCRIPTOR,proto_dot_types_dot_endorsement__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_BLOCKHEADER = _descriptor.Descriptor(
  name='BlockHeader',
  full_name='iotextypes.BlockHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='core', full_name='iotextypes.BlockHeader.core', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='producerPubkey', full_name='iotextypes.BlockHeader.producerPubkey', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='iotextypes.BlockHeader.signature', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=233,
)


_BLOCKHEADERCORE = _descriptor.Descriptor(
  name='BlockHeaderCore',
  full_name='iotextypes.BlockHeaderCore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='iotextypes.BlockHeaderCore.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='iotextypes.BlockHeaderCore.height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='iotextypes.BlockHeaderCore.timestamp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='prevBlockHash', full_name='iotextypes.BlockHeaderCore.prevBlockHash', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='txRoot', full_name='iotextypes.BlockHeaderCore.txRoot', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deltaStateDigest', full_name='iotextypes.BlockHeaderCore.deltaStateDigest', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receiptRoot', full_name='iotextypes.BlockHeaderCore.receiptRoot', index=6,
      number=7, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logsBloom', full_name='iotextypes.BlockHeaderCore.logsBloom', index=7,
      number=8, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=236,
  serialized_end=438,
)


_BLOCKFOOTER = _descriptor.Descriptor(
  name='BlockFooter',
  full_name='iotextypes.BlockFooter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='endorsements', full_name='iotextypes.BlockFooter.endorsements', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='iotextypes.BlockFooter.timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=440,
  serialized_end=547,
)


_BLOCKBODY = _descriptor.Descriptor(
  name='BlockBody',
  full_name='iotextypes.BlockBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='actions', full_name='iotextypes.BlockBody.actions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=549,
  serialized_end=597,
)


_BLOCK = _descriptor.Descriptor(
  name='Block',
  full_name='iotextypes.Block',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='iotextypes.Block.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='body', full_name='iotextypes.Block.body', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='footer', full_name='iotextypes.Block.footer', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=599,
  serialized_end=725,
)


_RECEIPTS = _descriptor.Descriptor(
  name='Receipts',
  full_name='iotextypes.Receipts',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='receipts', full_name='iotextypes.Receipts.receipts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=727,
  serialized_end=776,
)


_EPOCHDATA = _descriptor.Descriptor(
  name='EpochData',
  full_name='iotextypes.EpochData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='num', full_name='iotextypes.EpochData.num', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='iotextypes.EpochData.height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gravityChainStartHeight', full_name='iotextypes.EpochData.gravityChainStartHeight', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=778,
  serialized_end=851,
)


_CHAINMETA = _descriptor.Descriptor(
  name='ChainMeta',
  full_name='iotextypes.ChainMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='height', full_name='iotextypes.ChainMeta.height', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='numActions', full_name='iotextypes.ChainMeta.numActions', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tps', full_name='iotextypes.ChainMeta.tps', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='epoch', full_name='iotextypes.ChainMeta.epoch', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tpsFloat', full_name='iotextypes.ChainMeta.tpsFloat', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=853,
  serialized_end=969,
)


_BLOCKMETA = _descriptor.Descriptor(
  name='BlockMeta',
  full_name='iotextypes.BlockMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='iotextypes.BlockMeta.hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='iotextypes.BlockMeta.height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='iotextypes.BlockMeta.timestamp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='numActions', full_name='iotextypes.BlockMeta.numActions', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='producerAddress', full_name='iotextypes.BlockMeta.producerAddress', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transferAmount', full_name='iotextypes.BlockMeta.transferAmount', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='txRoot', full_name='iotextypes.BlockMeta.txRoot', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receiptRoot', full_name='iotextypes.BlockMeta.receiptRoot', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='deltaStateDigest', full_name='iotextypes.BlockMeta.deltaStateDigest', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='logsBloom', full_name='iotextypes.BlockMeta.logsBloom', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=972,
  serialized_end=1211,
)


_BLOCKIDENTIFIER = _descriptor.Descriptor(
  name='BlockIdentifier',
  full_name='iotextypes.BlockIdentifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hash', full_name='iotextypes.BlockIdentifier.hash', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='height', full_name='iotextypes.BlockIdentifier.height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1213,
  serialized_end=1260,
)


_ACCOUNTMETA = _descriptor.Descriptor(
  name='AccountMeta',
  full_name='iotextypes.AccountMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='iotextypes.AccountMeta.address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='balance', full_name='iotextypes.AccountMeta.balance', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='iotextypes.AccountMeta.nonce', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pendingNonce', full_name='iotextypes.AccountMeta.pendingNonce', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='numActions', full_name='iotextypes.AccountMeta.numActions', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1262,
  serialized_end=1366,
)

_BLOCKHEADER.fields_by_name['core'].message_type = _BLOCKHEADERCORE
_BLOCKHEADERCORE.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BLOCKFOOTER.fields_by_name['endorsements'].message_type = proto_dot_types_dot_endorsement__pb2._ENDORSEMENT
_BLOCKFOOTER.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BLOCKBODY.fields_by_name['actions'].message_type = proto_dot_types_dot_action__pb2._ACTION
_BLOCK.fields_by_name['header'].message_type = _BLOCKHEADER
_BLOCK.fields_by_name['body'].message_type = _BLOCKBODY
_BLOCK.fields_by_name['footer'].message_type = _BLOCKFOOTER
_RECEIPTS.fields_by_name['receipts'].message_type = proto_dot_types_dot_action__pb2._RECEIPT
_CHAINMETA.fields_by_name['epoch'].message_type = _EPOCHDATA
_BLOCKMETA.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['BlockHeader'] = _BLOCKHEADER
DESCRIPTOR.message_types_by_name['BlockHeaderCore'] = _BLOCKHEADERCORE
DESCRIPTOR.message_types_by_name['BlockFooter'] = _BLOCKFOOTER
DESCRIPTOR.message_types_by_name['BlockBody'] = _BLOCKBODY
DESCRIPTOR.message_types_by_name['Block'] = _BLOCK
DESCRIPTOR.message_types_by_name['Receipts'] = _RECEIPTS
DESCRIPTOR.message_types_by_name['EpochData'] = _EPOCHDATA
DESCRIPTOR.message_types_by_name['ChainMeta'] = _CHAINMETA
DESCRIPTOR.message_types_by_name['BlockMeta'] = _BLOCKMETA
DESCRIPTOR.message_types_by_name['BlockIdentifier'] = _BLOCKIDENTIFIER
DESCRIPTOR.message_types_by_name['AccountMeta'] = _ACCOUNTMETA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BlockHeader = _reflection.GeneratedProtocolMessageType('BlockHeader', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKHEADER,
  '__module__' : 'proto.types.blockchain_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.BlockHeader)
  })
_sym_db.RegisterMessage(BlockHeader)

BlockHeaderCore = _reflection.GeneratedProtocolMessageType('BlockHeaderCore', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKHEADERCORE,
  '__module__' : 'proto.types.blockchain_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.BlockHeaderCore)
  })
_sym_db.RegisterMessage(BlockHeaderCore)

BlockFooter = _reflection.GeneratedProtocolMessageType('BlockFooter', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKFOOTER,
  '__module__' : 'proto.types.blockchain_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.BlockFooter)
  })
_sym_db.RegisterMessage(BlockFooter)

BlockBody = _reflection.GeneratedProtocolMessageType('BlockBody', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKBODY,
  '__module__' : 'proto.types.blockchain_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.BlockBody)
  })
_sym_db.RegisterMessage(BlockBody)

Block = _reflection.GeneratedProtocolMessageType('Block', (_message.Message,), {
  'DESCRIPTOR' : _BLOCK,
  '__module__' : 'proto.types.blockchain_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.Block)
  })
_sym_db.RegisterMessage(Block)

Receipts = _reflection.GeneratedProtocolMessageType('Receipts', (_message.Message,), {
  'DESCRIPTOR' : _RECEIPTS,
  '__module__' : 'proto.types.blockchain_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.Receipts)
  })
_sym_db.RegisterMessage(Receipts)

EpochData = _reflection.GeneratedProtocolMessageType('EpochData', (_message.Message,), {
  'DESCRIPTOR' : _EPOCHDATA,
  '__module__' : 'proto.types.blockchain_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.EpochData)
  })
_sym_db.RegisterMessage(EpochData)

ChainMeta = _reflection.GeneratedProtocolMessageType('ChainMeta', (_message.Message,), {
  'DESCRIPTOR' : _CHAINMETA,
  '__module__' : 'proto.types.blockchain_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.ChainMeta)
  })
_sym_db.RegisterMessage(ChainMeta)

BlockMeta = _reflection.GeneratedProtocolMessageType('BlockMeta', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKMETA,
  '__module__' : 'proto.types.blockchain_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.BlockMeta)
  })
_sym_db.RegisterMessage(BlockMeta)

BlockIdentifier = _reflection.GeneratedProtocolMessageType('BlockIdentifier', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKIDENTIFIER,
  '__module__' : 'proto.types.blockchain_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.BlockIdentifier)
  })
_sym_db.RegisterMessage(BlockIdentifier)

AccountMeta = _reflection.GeneratedProtocolMessageType('AccountMeta', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTMETA,
  '__module__' : 'proto.types.blockchain_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.AccountMeta)
  })
_sym_db.RegisterMessage(AccountMeta)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



from iotexetl.utils import string_utils


def map_log(block, log):
    return {
        'type': 'log',
        'height': log.blkHeight,
        'action_hash': log.actHash.hex(),
        'contract_address': log.contractAddress,
        'topics': [string_utils.base64_string(topic) for topic in log.topics],
        'data': string_utils.base64_string(log.data),
        'index': log.index,
        'timestamp': block.header.core.timestamp.ToJsonString()
    }


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/types/endorsement.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/types/endorsement.proto',
  package='iotextypes',
  syntax='proto3',
  serialized_options=b'\n\"com.github.iotexproject.grpc.typesP\001Z5github.com/iotexproject/iotex-proto/golang/iotextypes',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1dproto/types/endorsement.proto\x12\niotextypes\x1a\x1fgoogle/protobuf/timestamp.proto\"a\n\x0b\x45ndorsement\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x10\n\x08\x65ndorser\x18\x02 \x01(\x0c\x12\x11\n\tsignature\x18\x03 \x01(\x0c\x42]\n\"com.github.iotexproject.grpc.typesP\x01Z5github.com/iotexproject/iotex-proto/golang/iotextypesb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])




_ENDORSEMENT = _descriptor.Descriptor(
  name='Endorsement',
  full_name='iotextypes.Endorsement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='iotextypes.Endorsement.timestamp', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endorser', full_name='iotextypes.Endorsement.endorser', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signature', full_name='iotextypes.Endorsement.signature', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=175,
)

_ENDORSEMENT.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['Endorsement'] = _ENDORSEMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Endorsement = _reflection.GeneratedProtocolMessageType('Endorsement', (_message.Message,), {
  'DESCRIPTOR' : _ENDORSEMENT,
  '__module__' : 'proto.types.endorsement_pb2'
  # @@protoc_insertion_point(class_scope:iotextypes.Endorsement)
  })
_sym_db.RegisterMessage(Endorsement)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
